#ifndef SOFTPWM_H 
#define SOFTPWM_H 

#include <ctype.h>
#include "main.h"
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/wdt.h>


//! Compiler specific defines
#if defined(__ICCAVR__)
  // correct an IAR definition for Watchdog Timer Control Register,
  // may not be needed in later versions of IAR or for other AVR devices.
  #define WDTCSR  WDTCR
#elif __GNUC__ > 0
  // redefine some macros
  #define __watchdog_reset()    wdt_reset()
#endif

//! Pin mappings
#define CHMAX       8    // maximum number of PWM channels
#define PWMDEFAULT  0x00  // default PWM value at start up for all channels

#define CH0_CLEAR (pinlevelD &= ~(1 << PD0)) // map CH0 to PD0
#define CH1_CLEAR (pinlevelD &= ~(1 << PD1)) // map CH1 to PD1
#define CH2_CLEAR (pinlevelD &= ~(1 << PD4)) // map CH2 to PD4 
#define CH3_CLEAR (pinlevelD &= ~(1 << PD5)) // map CH3 to PD5
#define CH4_CLEAR (pinlevelD &= ~(1 << PD6)) // map CH4 to PD6
#define CH5_CLEAR (pinlevelD &= ~(1 << PD7)) // map CH5 to PD7


#define CH6_CLEAR (pinlevelB &= ~(1 << PB4)) // map CH6 to PB4
#define CH7_CLEAR (pinlevelB &= ~(1 << PB7)) // map CH6 to PB4
//#define CH8_CLEAR (pinlevelB &= ~(1 << PB6)) // map CH6 to PB4
//#define CH9_CLEAR (pinlevelB &= ~(1 << PB7)) // map CH7 to PB7

// Set bits corresponding to pin usage above
#define PORTB_MASK  (1 << PB4)|(1 << PB7)
#define PORTD_MASK  (1 << PD0)|(1 << PD1)|(1 << PD4)|(1 << PD5)|(1 << PD6)|(1 << PD7)


// prototypes
void InitSoftPWM(void);

#endif
